# Documentation for `Hyperpipe`
::: photonai.base.Hyperpipe
    selection:
      members:
        - __init__
        - add
        - fit
        - predict
        - predict_proba
        - load_optimum_pipe
        - inverse_transform_pipeline
        - copy_me
        - get_permutation_feature_importances
